@@ -124,7 +124,7 @@ c
         mcumold = mcum
         mcum = mcum + m(i)
 
-        if(m(i) .eq. 0) then
+        if(m(i).eq.0) then
            mstar(i) = 1
         else
            mstar(i) = m(i)
@@ -148,8 +148,99 @@ c
          endif
         end do
       end do
-
+      
       end subroutine wcPLE
+      
+      
+      subroutine wc2(n,gtime,ctime,count,mc,m,
+     *             cen,ucen,nd,udt,tot,gap,event,
+     *             r,d,sest,var)
+      integer n,mc,nd,cumni,curj,tot,m(n)
+      double precision gtime(n,mc),cen(n,mc)
+      double precision gap(tot),event(tot)
+      double precision ctime(n)
+      double precision count(n),ucen(n)
+      double precision udt(nd),r(nd),d(nd)
+      double precision sest(nd),var(nd)
+      double precision hai,fai,phi,w
+
+c     cumni is a counter : m(i-1) where m(0) = 0
+c     curj is a counter within a counter
+
+      cumni=0 
+      do 11 i=1,n
+         do 10 j=1,m(i)
+            curj = cumni + j
+            gtime(i,j) = gap(curj)
+            cen(i,j) = event(curj)   
+ 10      continue
+         cumni=cumni+m(i)
+ 11   continue 
+
+      do 30 k=1,nd
+         r(k)=0.
+         d(k)=0.
+         do 25 i=1,n
+            if (count(i).gt.1.) then
+               do 20 j=1,idint(ucen(i))
+                  if(gtime(i,j).ge.udt(k)) then
+                     r(k)=r(k)+ctime(i)/ucen(i)
+                  endif
+                  if(gtime(i,j).eq.udt(k)) then
+                     d(k)=d(k)+ctime(i)/ucen(i)
+                  endif
+ 20            continue
+            else
+               if(gtime(i,1).ge.udt(k)) r(k)=r(k)+ctime(i)
+               if((gtime(i,1).eq.udt(k)).and.(cen(i,j).gt.0))
+     *              d(k)=d(k)+ctime(i)
+            endif
+ 25      continue
+ 30   continue
+
+c Calculate survivor estimate at time T (i.e. time nd)
+      sest(1)=1.-d(1)/r(1)
+      do 50 i=2,nd
+         sest(i)=sest(i-1)*(1.-d(i)/r(i))
+ 50   continue
+
+c Calculate standard error
+      do 180 k=1,nd
+         phi=0.
+         do 170 i=1,n
+            fai=0.
+            w=0.
+            do 140 k2=1,k
+               hai=0.
+               if (count(i).gt.1.) then
+                  do 130 j=1,idint(ucen(i))
+                     if(gtime(i,j).ge.udt(k2)) then
+                        hai=hai+ctime(i)/ucen(i)
+                     endif
+ 130              continue
+               elseif (gtime(i,1).ge. udt(k2)) then
+                  hai=hai+ctime(i)
+               endif
+               w=w+hai*d(k2)/(r(k2)*r(k2))
+ 140        continue
+            do 160 j2=1,idint(ucen(i))
+               if (gtime(i,j2).lt. udt(k)) then
+                  do 150 k3=1,nd
+                     if (gtime(i,j2).eq. udt(k3)) then
+                        fai=fai+ctime(i)/(ucen(i)*r(k3))
+                     endif
+ 150              continue
+               endif
+ 160        continue
+            phi=phi+(w-fai)*(w-fai)
+ 170     continue
+         var(k)=dsqrt(phi)*sest(k)
+ 180  continue
+
+      return
+      end subroutine wc2
+
+     
 
 
 c
@@ -173,8 +264,7 @@ c
         double precision S,Zhatold,lambold
         double precision alphaold,distall,dZhat,dlambda,dalpha,stemp
 
-
-
+        
         iter = 0
 c
         do 5 i=1,n
@@ -207,9 +297,11 @@ c
 30              continue
 c
                 alphaold = alpha
+       
                 call estalpha(n,m,numdis,distinct,numdead,AtRisk,lambda,
      1          alpha,tol,maxiter,istatus2)
 c
+        
                 if((istatus2.eq.0)) then
                         istopck=1
                         istatus=0
@@ -246,6 +338,7 @@ c
 c
         end do
 c
+       
         return
         end subroutine emalgo
 
@@ -268,7 +361,7 @@ c       double precision moalpha,Soalpha,S
         double precision  fu,fv,fw,fx,x,tol3
         double precision  dabs,dsqrt,d1mach
 
-
+                
         status=1
 c  c is the squared inverse of the golden ratio
         c=0.5d0*(3.0d0-dsqrt(5.0d0))
@@ -297,6 +390,7 @@ c
         e=0.0d0
 
         call loglik(n,m,numdis,distinct,numdead,AtRisk,lambda,x,l1)
+                
         fx=-1.d0*l1
 
         fv=fx
@@ -427,6 +521,7 @@ c       double precision moalpha
         double precision distinct,lambda,tol,Soalpha,S
         double precision l1, alpha,C1,C2,C3,q1,q2
 c
+                
         C3 = 0.d0
 c
         do 10 i=1,n
@@ -456,8 +551,7 @@ c
 
         l1=q1 - q2 + C3
 c        call dblepr("l1",2,l1,1)
-
-        return
+                
         end subroutine loglik
 
           
